#%%
import re
from collections import Counter
from ar_corrector.io_handler import *
import os
from ar_corrector.config import *

class Preprocessor:
    def __init__(self):
        pass
    def clean(self, txt):
        res = re.sub(r'[^\w\s]+', '', txt)
        res = re.sub(r'[\d_\-]+', ' ', res)
        res = re.sub(r'\s+', ' ', res)
        res = re.sub(r'[^ابتةثجحخدذرزسشصضطظعغفقكلمنهويءآأؤإئ\s]+', '', res)
        res = re.sub(r'\s+', ' ', res)
        return res.strip()

    def tokenize(self, txt):
        return txt.split()
    
    def __call__(self, txt):
        ctxt = self.clean(txt)
        txt_arr = self.tokenize(ctxt)
        word_counts = Counter(txt_arr)
        
        save_dict_file(config['vocabs_dict'], dict(word_counts))

    def get_letters(self, txt):
        res = self.clean(txt)
        chars = set(res)
        return chars
# %%



import pickle

def read_txt_file(path):
    with open(path, 'r', encoding='utf-8-sig') as myfile:
        res = myfile.read()
    return res

def save_dict_file(path, dict_obj):
    with open(path, 'wb') as myfile:
        pickle.dump(dict_obj, myfile, protocol=pickle.HIGHEST_PROTOCOL)

def load_dict_file(path):
    with open(path, 'rb') as myfile:
        dict_obj = pickle.load(myfile)
        return dict_obj


import unittest
import os
from ar_corrector.io_handler import *
class TestIoHandler(unittest.TestCase):
    
    def test_read_txt_file(self):
        path = os.path.dirname(__file__) + '/../data/TXT_No_header.txt'
        res = read_txt_file(path)
        self.assertIsNotNone(res)

    def test_read_text_file_content(self):
        path = os.path.dirname(__file__) + '/../data/TXT_No_header.txt'
        res = read_txt_file(path)
        self.assertEqual(res[:6], 'الرحلة')

if __name__ == '__main__':
    unittest.main()